Struct EuvNavbarLinkProps
Source pub struct EuvNavbarLinkProps {
pub route_signal: Signal<String>,
pub item: EuvNavbarItem,
}
The current route signal.
The navbar item to render.
Performs copy-assignment from
source.
Read more
Formats the struct fields as a debug struct, skipping excluded fields.
Arguments
&mut std::fmt::Formatter<'_> - The formatter to write the representation into.
Returns
std::fmt::Result - Success or failure of the formatting operation.
Returns the “default value” for a type.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
🔬This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more
Uses borrowed data to replace owned data, usually by cloning.
Read more
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.
Perform a zero-cost type-safe upcast to a wider ref type within the Wasm
bindgen generics type system.
Read more
Perform a zero-cost type-safe upcast to a wider type within the Wasm
bindgen generics type system.
Read more