pub struct EuvTimelineItem {
pub title: &'static str,
pub description: &'static str,
pub time: &'static str,
}Expand description
One entry of the euv_timeline event log.
A timeline item is a headline, an optional body, and an optional timestamp. The empty fields are skipped at render time so a terse one-line entry does not leave an empty gap in the column.
Fields
title: &'static strThe entry headline rendered in c_euv_timeline_title.
description: &'static strThe optional entry body rendered in c_euv_timeline_desc.
time: &'static strThe optional timestamp rendered in the monospace
c_euv_timeline_time style (skipped when empty).
Implementations
Sourceimpl EuvTimelineItem
impl EuvTimelineItem
pub fn get_title(&self) -> &'static str
pub fn get_mut_title(&mut self) -> &mut &'static str
pub fn set_title(&mut self, val: &'static str) -> &mut Self
pub fn get_description(&self) -> &'static str
pub fn get_mut_description(&mut self) -> &mut &'static str
pub fn set_description(&mut self, val: &'static str) -> &mut Self
pub fn get_time(&self) -> &'static str
pub fn get_mut_time(&mut self) -> &mut &'static str
pub fn set_time(&mut self, val: &'static str) -> &mut Self