EuvVirtualListConfig

Struct EuvVirtualListConfig 

pub struct EuvVirtualListConfig {
    pub id: String,
    pub total_count: usize,
    pub item_height: i32,
    pub overscan_count: usize,
}
Configuration for a virtual list instance.

Defines the total item count, item height, overscan buffer size, and a unique container id for a virtual list. This struct allows multiple virtual list instances with different configurations on the same page.

Fields

id: String

The unique identifier for this virtual list container. Used to reference the scroll container element.

total_count: usize

The total number of items in the list.

item_height: i32

The fixed height of each item in pixels.

overscan_count: usize

The number of extra items to render above and below the visible viewport.

Implementations

Source

impl EuvVirtualListConfig

pub fn get_id(&self) -> &String

pub fn get_mut_id(&mut self) -> &mut String

pub fn set_id(&mut self, val: String) -> &mut Self

pub fn get_total_count(&self) -> usize

pub fn get_mut_total_count(&mut self) -> &mut usize

pub fn set_total_count(&mut self, val: usize) -> &mut Self

pub fn get_item_height(&self) -> i32

pub fn get_mut_item_height(&mut self) -> &mut i32

pub fn set_item_height(&mut self, val: i32) -> &mut Self

pub fn get_overscan_count(&self) -> usize

pub fn get_mut_overscan_count(&mut self) -> &mut usize

pub fn set_overscan_count(&mut self, val: usize) -> &mut Self

Source

impl EuvVirtualListConfig

pub fn new( id: String, total_count: usize, item_height: i32, overscan_count: usize, ) -> Self