UseEuvBrowser

Struct UseEuvBrowser 

pub struct UseEuvBrowser {
Show 15 fields pub local_key: Signal<String>, pub local_value: Signal<String>, pub local_result: Signal<String>, pub session_key: Signal<String>, pub session_value: Signal<String>, pub session_result: Signal<String>, pub clipboard_text: Signal<String>, pub clipboard_result: Signal<String>, pub window_size: Signal<String>, pub user_agent: Signal<String>, pub language: Signal<String>, pub location_url: Signal<String>, pub location_origin_val: Signal<String>, pub location_pathname_val: Signal<String>, pub console_input: Signal<String>,
}
Reactive state for the browser API features.

Aggregates all signals needed for the localStorage, sessionStorage, clipboard, window, navigator, location, and console sections.

Fields

local_key: Signal<String>

The localStorage key input.

local_value: Signal<String>

The localStorage value input.

local_result: Signal<String>

The localStorage operation result.

session_key: Signal<String>

The sessionStorage key input.

session_value: Signal<String>

The sessionStorage value input.

session_result: Signal<String>

The sessionStorage operation result.

clipboard_text: Signal<String>

The clipboard text input.

clipboard_result: Signal<String>

The clipboard operation result.

window_size: Signal<String>

The window size display.

user_agent: Signal<String>

The user agent string.

language: Signal<String>

The navigator language.

location_url: Signal<String>

The location href.

location_origin_val: Signal<String>

The location origin.

location_pathname_val: Signal<String>

The location pathname.

console_input: Signal<String>

The console message input.

Implementations

Source

impl UseEuvBrowser

Implementation of browser API functionality.

pub fn use_browser_state() -> UseEuvBrowser

Creates browser API state for localStorage, sessionStorage, clipboard, and navigator access.

Returns
  • UseEuvBrowser: The browser API state.
pub fn local_storage_get(key: &str) -> Option<String>

Reads a value from the browser localStorage.

Arguments
  • &str: The key to look up.
Returns
  • Option<String>: The stored value if found, or None.
pub fn local_storage_set(key: &str, value: &str)

Writes a key-value pair to the browser localStorage.

Arguments
  • &str: The key to store.
  • &str: The value to store.
pub fn on_local_storage_set(self) -> Option<Rc<dyn Fn(Event)>>

Creates a click event handler that sets a localStorage item.

Arguments
  • UseEuvBrowser: The browser API state.
Returns
  • Option<Rc<dyn Fn(Event)>>: A click handler to set the localStorage item.
pub fn on_local_storage_get(self) -> Option<Rc<dyn Fn(Event)>>

Creates a click event handler that gets a localStorage item.

Arguments
  • UseEuvBrowser: The browser API state.
Returns
  • Option<Rc<dyn Fn(Event)>>: A click handler to get the localStorage item.
pub fn on_local_storage_remove(self) -> Option<Rc<dyn Fn(Event)>>

Creates a click event handler that removes a localStorage item.

Arguments
  • UseEuvBrowser: The browser API state.
Returns
  • Option<Rc<dyn Fn(Event)>>: A click handler to remove the localStorage item.
pub fn on_session_storage_set(self) -> Option<Rc<dyn Fn(Event)>>

Creates a click event handler that sets a sessionStorage item.

Arguments
  • UseEuvBrowser: The browser API state.
Returns
  • Option<Rc<dyn Fn(Event)>>: A click handler to set the sessionStorage item.
pub fn on_session_storage_get(self) -> Option<Rc<dyn Fn(Event)>>

Creates a click event handler that gets a sessionStorage item.

Arguments
  • UseEuvBrowser: The browser API state.
Returns
  • Option<Rc<dyn Fn(Event)>>: A click handler to get the sessionStorage item.
pub fn on_session_storage_remove(self) -> Option<Rc<dyn Fn(Event)>>

Creates a click event handler that removes a sessionStorage item.

Arguments
  • UseEuvBrowser: The browser API state.
Returns
  • Option<Rc<dyn Fn(Event)>>: A click handler to remove the sessionStorage item.
pub fn on_clipboard_copy(self) -> Option<Rc<dyn Fn(Event)>>

Creates a click event handler that copies text to clipboard.

Arguments
  • UseEuvBrowser: The browser API state.
Returns
  • Option<Rc<dyn Fn(Event)>>: A click handler to copy text to clipboard.
pub fn on_clipboard_paste(self) -> Option<Rc<dyn Fn(Event)>>

Creates a click event handler that reads text from clipboard.

Arguments
  • UseEuvBrowser: The browser API state.
Returns
  • Option<Rc<dyn Fn(Event)>>: A click handler to read text from clipboard.
pub fn on_window_refresh_size(self) -> Option<Rc<dyn Fn(Event)>>

Creates a click event handler that refreshes the window size display.

Arguments
  • UseEuvBrowser: The browser API state.
Returns
  • Option<Rc<dyn Fn(Event)>>: A click handler to refresh the window size.
pub fn on_console_log( console_input: Signal<String>, ) -> Option<Rc<dyn Fn(Event)>>

Creates a click event handler that logs a console message.

Arguments
  • Signal<String>: The console input signal.
Returns
  • Option<Rc<dyn Fn(Event)>>: A click handler for console.log.
pub fn on_console_warn( console_input: Signal<String>, ) -> Option<Rc<dyn Fn(Event)>>

Creates a click event handler that warns a console message.

Arguments
  • Signal<String>: The console input signal.
Returns
  • Option<Rc<dyn Fn(Event)>>: A click handler for console.warn.
pub fn on_console_error( console_input: Signal<String>, ) -> Option<Rc<dyn Fn(Event)>>

Creates a click event handler that errors a console message.

Arguments
  • Signal<String>: The console input signal.
Returns
  • Option<Rc<dyn Fn(Event)>>: A click handler for console.error.
Source

impl UseEuvBrowser

pub fn get_local_key(&self) -> Signal<String>

pub fn get_mut_local_key(&mut self) -> &mut Signal<String>

pub fn set_local_key(&mut self, val: Signal<String>) -> &mut Self

pub fn get_local_value(&self) -> Signal<String>

pub fn get_mut_local_value(&mut self) -> &mut Signal<String>

pub fn set_local_value(&mut self, val: Signal<String>) -> &mut Self

pub fn get_local_result(&self) -> Signal<String>

pub fn get_mut_local_result(&mut self) -> &mut Signal<String>

pub fn set_local_result(&mut self, val: Signal<String>) -> &mut Self

pub fn get_session_key(&self) -> Signal<String>

pub fn get_mut_session_key(&mut self) -> &mut Signal<String>

pub fn set_session_key(&mut self, val: Signal<String>) -> &mut Self

pub fn get_session_value(&self) -> Signal<String>

pub fn get_mut_session_value(&mut self) -> &mut Signal<String>

pub fn set_session_value(&mut self, val: Signal<String>) -> &mut Self

pub fn get_session_result(&self) -> Signal<String>

pub fn get_mut_session_result(&mut self) -> &mut Signal<String>

pub fn set_session_result(&mut self, val: Signal<String>) -> &mut Self

pub fn get_clipboard_text(&self) -> Signal<String>

pub fn get_mut_clipboard_text(&mut self) -> &mut Signal<String>

pub fn set_clipboard_text(&mut self, val: Signal<String>) -> &mut Self

pub fn get_clipboard_result(&self) -> Signal<String>

pub fn get_mut_clipboard_result(&mut self) -> &mut Signal<String>

pub fn set_clipboard_result(&mut self, val: Signal<String>) -> &mut Self

pub fn get_window_size(&self) -> Signal<String>

pub fn get_mut_window_size(&mut self) -> &mut Signal<String>

pub fn set_window_size(&mut self, val: Signal<String>) -> &mut Self

pub fn get_user_agent(&self) -> Signal<String>

pub fn get_mut_user_agent(&mut self) -> &mut Signal<String>

pub fn set_user_agent(&mut self, val: Signal<String>) -> &mut Self

pub fn get_language(&self) -> Signal<String>

pub fn get_mut_language(&mut self) -> &mut Signal<String>

pub fn set_language(&mut self, val: Signal<String>) -> &mut Self

pub fn get_location_url(&self) -> Signal<String>

pub fn get_mut_location_url(&mut self) -> &mut Signal<String>

pub fn set_location_url(&mut self, val: Signal<String>) -> &mut Self

pub fn get_location_origin_val(&self) -> Signal<String>

pub fn get_mut_location_origin_val(&mut self) -> &mut Signal<String>

pub fn set_location_origin_val(&mut self, val: Signal<String>) -> &mut Self

pub fn get_location_pathname_val(&self) -> Signal<String>

pub fn get_mut_location_pathname_val(&mut self) -> &mut Signal<String>

pub fn set_location_pathname_val(&mut self, val: Signal<String>) -> &mut Self

pub fn get_console_input(&self) -> Signal<String>

pub fn get_mut_console_input(&mut self) -> &mut Signal<String>

pub fn set_console_input(&mut self, val: Signal<String>) -> &mut Self