pub struct UpdateResult {
pub doc_status: bool,
pub version: String,
pub updating: bool,
}Expand description
The result returned by a cache update closure.
The UI component uses this value to update its internal state signals without knowing how the update check was performed.
Fields
doc_status: boolWhether the documentation build succeeded.
version: StringThe latest version string of the crate.
updating: boolWhether a cache update operation was triggered.
Implementations
Sourceimpl UpdateResult
impl UpdateResult
pub fn get_doc_status(&self) -> bool
pub fn get_mut_doc_status(&mut self) -> &mut bool
pub fn set_doc_status(&mut self, val: bool) -> &mut Self
pub fn get_version(&self) -> &String
pub fn get_mut_version(&mut self) -> &mut String
pub fn set_version(&mut self, val: String) -> &mut Self
pub fn get_updating(&self) -> bool
pub fn get_mut_updating(&mut self) -> &mut bool
pub fn set_updating(&mut self, val: bool) -> &mut Self